import { create } from 'zustand';
import { supabase } from '@/lib/supabase/client';
import { User } from '@supabase/supabase-js';

interface AuthState {
  user: User | null;
  isLoading: boolean;
  error: Error | null;
  checkAuth: () => Promise<void>;
  clearError: () => void;
}

export const useAuth = create<AuthState>((set) => ({
  user: null,
  isLoading: true,
  error: null,

  checkAuth: async () => {
    try {
      const { data: { user }, error } = await supabase.auth.getUser();
      if (error) throw error;
      set({ user, isLoading: false });
    } catch (error) {
      set({ error: error as Error, isLoading: false });
    }
  },

  clearError: () => set({ error: null }),
}));

// Initialize auth state
if (typeof window !== 'undefined') {
  useAuth.getState().checkAuth();

  // Listen for auth changes
  supabase.auth.onAuthStateChange((event, session) => {
    useAuth.setState({
      user: session?.user ?? null,
      isLoading: false,
    });
  });
}